==> tokenchannel-java11-starter-0.12.0.RELEASE-sources.jar: io/tokenchannel/TokenChannelAutoConfiguration.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.tokenchannel;

import com.google.gson.Gson;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Role;

@Configuration
public class TokenChannelAutoConfiguration {

    @ConditionalOnMissingBean
    @Bean
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    public TokenChannel tokenChannel(TokenChannelProperties tokenChannelProperties, Gson gson) {
        return new TokenChannel(tokenChannelProperties, gson);
    }

    @ConditionalOnMissingBean
    @ConfigurationProperties(prefix = "tokenchannel")
    @Bean
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    public TokenChannelProperties tokenChannelProperties() {
        return new TokenChannelProperties();
    }

    @ConditionalOnMissingBean
    @Bean
    public Gson gson() {
        return new Gson();
    }
}

==> tokenchannel-java11-starter-0.16.RELEASE-sources.jar: io/tokenchannel/TokenChannelAutoConfiguration.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.tokenchannel;

import com.google.gson.Gson;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Role;

@Configuration
public class TokenChannelAutoConfiguration {

    @ConditionalOnMissingBean
    @Bean
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    public TokenChannel tokenChannel(TokenChannelProperties tokenChannelProperties) {
        return new TokenChannel(tokenChannelProperties);
    }

    @ConditionalOnMissingBean
    @ConfigurationProperties(prefix = "tokenchannel")
    @Bean
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    public TokenChannelProperties tokenChannelProperties() {
        return new TokenChannelProperties();
    }
}
